@@ -3,11 +3,12 @@ from time import sleep
 
 import requests
 
+from calaccess_processed.proxies import OCDProxyModelMixin
 from calaccess_processed.models import CalAccessBaseModel
 from calaccess_processed_filings.managers import FilingsManager
 
 
-class FilingBaseModel(CalAccessBaseModel):
+class FilingBaseModel(CalAccessBaseModel, OCDProxyModelMixin):
     """
     Base model for all the filings models.
     """
@@ -22,6 +23,16 @@ class FilingBaseModel(CalAccessBaseModel):
         abstract = True
         app_label = "calaccess_processed_filings"
 
+    @property
+    def file_name(self):
+        """
+        The name for the csv to which the model's contents will be dumped.
+
+        If the model is a flat model proxy, return the model's verbose_name_plural
+        in CamelCase. Otherwise, return the object_name of the base_model.
+        """
+        return self._meta.object_name
+
     @property
     def pdf_url(self):
         """
